@@ -54,6 +54,7 @@ func TestNewDNSProvider(t *testing.T) {
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
 			defer envTest.RestoreEnv()
+
 			envTest.ClearEnv()
 
 			envTest.Apply(test.envVars)
@@ -161,6 +162,7 @@ func TestDNSProvider_Present(t *testing.T) {
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
 			defer envTest.RestoreEnv()
+
 			envTest.ClearEnv()
 
 			provider := test.builder.Build(t)
@@ -204,6 +206,7 @@ func TestDNSProvider_CleanUp(t *testing.T) {
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
 			defer envTest.RestoreEnv()
+
 			envTest.ClearEnv()
 
 			provider := test.builder.Build(t)
@@ -224,6 +227,7 @@ func TestLivePresent(t *testing.T) {
 	}
 
 	envTest.RestoreEnv()
+
 	provider, err := NewDNSProvider()
 	require.NoError(t, err)
 
@@ -237,6 +241,7 @@ func TestLiveCleanUp(t *testing.T) {
 	}
 
 	envTest.RestoreEnv()
+
 	provider, err := NewDNSProvider()
 	require.NoError(t, err)
 
@@ -252,6 +257,13 @@ func mockBuilder() *servermock.Builder[*DNSProvider] {
 			EnvEndpoint: server.URL,
 		})
 
-		return NewDNSProvider()
+		provider, err := NewDNSProvider()
+		if err != nil {
+			return nil, err
+		}
+
+		provider.client.HTTPClient = server.Client()
+
+		return provider, nil
 	})
 }
