@@ -10,8 +10,10 @@ import (
 	"strings"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/clientdebug"
 	"github.com/vultr/govultr/v3"
 	"golang.org/x/oauth2"
 )
@@ -28,6 +30,8 @@ const (
 	EnvHTTPTimeout        = envNamespace + "HTTP_TIMEOUT"
 )
 
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 // Config is used to configure the creation of the DNSProvider.
 type Config struct {
 	APIKey             string
@@ -35,7 +39,7 @@ type Config struct {
 	PollingInterval    time.Duration
 	TTL                int
 	HTTPClient         *http.Client
-	HTTPTimeout        time.Duration
+	HTTPTimeout        time.Duration // TODO(ldez): remove in v5
 }
 
 // NewDefaultConfig returns a default configuration for the DNSProvider.
@@ -81,7 +85,7 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 	authClient := OAuthStaticAccessToken(config.HTTPClient, config.APIKey)
 	authClient.Timeout = config.HTTPTimeout
 
-	client := govultr.NewClient(authClient)
+	client := govultr.NewClient(clientdebug.Wrap(authClient))
 
 	return &DNSProvider{client: client, config: config}, nil
 }
@@ -103,7 +107,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		return fmt.Errorf("vultr: %w", err)
 	}
 
-	req := govultr.DomainRecordReq{
+	req := govultr.DomainRecordCreateReq{
 		Name:     subDomain,
 		Type:     "TXT",
 		Data:     `"` + info.Value + `"`,
@@ -132,6 +136,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	}
 
 	var allErr []string
+
 	for _, rec := range records {
 		err := d.client.DomainRecord.Delete(ctx, zoneDomain, rec.ID)
 		if err != nil {
@@ -201,6 +206,7 @@ func (d *DNSProvider) findTxtRecords(ctx context.Context, domain, fqdn string) (
 	listOptions := &govultr.ListOptions{PerPage: 25}
 
 	var records []govultr.DomainRecord
+
 	for {
 		result, meta, resp, err := d.client.DomainRecord.List(ctx, zoneDomain, listOptions)
 		if err != nil {
